@@ -1,10 +1,10 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 set -eu
 set -o pipefail
 
 FILE="$1"
 
-cpp -E -dD "$FILE" | awk '
+${CXX:-cpp} -E -dD "$FILE" | awk '
 	/#define E/ { print "E(" $2 ");" }
 '
