@@ -1,10 +1,8 @@
 #include <assert.h>
 #include <stdint.h>
-#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <sys/mman.h>
-#include <errno.h>
 
 #include "ngs.h"
 
